@@ -20,6 +20,7 @@ from unittest import mock
 
 import ddt
 
+from glanceclient.common import utils as common_utils
 from glanceclient import exc
 from glanceclient.tests.unit.v2 import base
 from glanceclient.tests import utils
@@ -674,6 +675,19 @@ data_fixtures = {
             ]},
         ),
     },
+    '/v2/images/3a4560a1-e585-443e-9b39-553b46ec92d1/tasks': {
+        'GET': (
+            {},
+            {'tasks': [
+                {
+                    'id': '6f99bf80-2ee6-47cf-acfe-1f1fabb7e810',
+                    'status': 'succeed',
+                    'message': 'Copied 44 MiB',
+                    'updated_at': '2021-03-01T18:28:26.000000'
+                }
+            ]},
+        ),
+    },
 }
 
 schema_fixtures = {
@@ -715,6 +729,22 @@ class TestController(testtools.TestCase):
         self.controller = base.BaseController(self.api, self.schema_api,
                                               images.Controller)
 
+    def test_image_tasks_supported(self):
+        with mock.patch.object(common_utils,
+                               'has_version') as mock_has_version:
+            mock_has_version.return_value = True
+            image_tasks = self.controller.get_associated_image_tasks(
+                '3a4560a1-e585-443e-9b39-553b46ec92d1')
+            self.assertEqual(1, len(image_tasks['tasks']))
+
+    def test_image_tasks_not_supported(self):
+        with mock.patch.object(common_utils,
+                               'has_version') as mock_has_version:
+            mock_has_version.return_value = False
+            self.assertRaises(exc.HTTPNotImplemented,
+                              self.controller.get_associated_image_tasks,
+                              '3a4560a1-e585-443e-9b39-553b46ec92d1')
+
     def test_list_images(self):
         images = self.controller.list()
         self.assertEqual('3a4560a1-e585-443e-9b39-553b46ec92d1', images[0].id)
@@ -1171,7 +1201,7 @@ class TestController(testtools.TestCase):
         body = ''.join([b for b in body])
         self.assertEqual('GOODCHECKSUM', body)
 
-    def test_image_import(self):
+    def test_image_import_web_download(self):
         uri = 'http://example.com/image.qcow'
         data = [('method', {'name': 'web-download',
                  'uri': uri})]
@@ -1181,6 +1211,24 @@ class TestController(testtools.TestCase):
                   data)]
         self.assertEqual(expect, self.api.calls)
 
+    def test_image_import_glance_download(self):
+        region = 'REGION2'
+        remote_image_id = '75baf7b6-253a-11ed-8307-4b1057986a78'
+        image_id = '606b0e88-7c5a-4d54-b5bb-046105d4de6f'
+        service_interface = 'public'
+        data = [('method',
+                 {'name': 'glance-download',
+                  'glance_region': region,
+                  'glance_image_id': remote_image_id,
+                  'glance_service_interface': service_interface})]
+        self.controller.image_import(
+            image_id, 'glance-download', remote_region=region,
+            remote_image_id=remote_image_id,
+            remote_service_interface=service_interface)
+        expect = [('POST', '/v2/images/%s/import' % image_id, {},
+                  data)]
+        self.assertEqual(expect, self.api.calls)
+
     def test_download_no_data(self):
         resp = utils.FakeResponse(headers={}, status_code=204)
         self.controller.controller.http_client.get = mock.Mock(
